---
title: Support adapters with custom CA certificates
---

This guide will walk you through the steps to support adapters with custom CA certificates for infrahub-sync.

## Step 1: Create a subdirectory for your custom CA certificates

```bash
sudo mkdir /usr/local/share/ca-certificates/custom-ca
```

## Step 2: Copy your root CA custom certificate into the folder you just created

```bash
cp customRCA.crt /usr/local/share/ca-certificates/custom-ca/
```

## Step 3: Run the following command to load the certificates on your system trusted root certificate store

```bash
sudo update-ca-certificates
```

## Step 4: Use the following command to set `REQUESTS_CA_BUNDLE` environment variable

```bash
export REQUESTS_CA_BUNDLE=/etc/ssl/certs/ca-certificates.crt
```
